@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: API2.pm,v 1.79 2005/03/23 16:42:06 fredo Exp $
+#   $Id: API2.pm,v 1.80 2005/06/10 16:12:49 fredo Exp $
 #
 #=======================================================================
 
@@ -37,7 +37,7 @@ BEGIN {
 
     use vars qw( $VERSION $seq @FontDirs );
 
-    ($VERSION) = ('$Revision: 1.79 $' =~ /Revision: (\S+)\s/)[0];  # $Date: 2005/03/23 16:42:06 $
+    ($VERSION) = ('$Revision: 1.80 $' =~ /Revision: (\S+)\s/)[0];  # $Date: 2005/06/10 16:12:49 $
 
     @FontDirs = ( (map { "$_/PDF/API2/fonts" } @INC), 
         qw[ /usr/share/fonts /usr/local/share/fonts c:/windows/fonts c:/winnt/fonts ] );
@@ -135,8 +135,16 @@ to minimize possible memory requirements later-on.
 B<Example:>
 
     $pdf = PDF::API2->new();
+    ...
+    print $pdf->stringify;
+
+    $pdf = PDF::API2->new();
+    ...
+    $pdf->saveas("our/new.pdf");
 
     $pdf = PDF::API2->new(-file => 'our/new.pdf');
+    ...
+    $pdf->save;
 
 =cut
 
@@ -171,6 +179,16 @@ sub new {
 
 Opens an existing PDF for modification.
 
+B<Example:>
+
+    $pdf = PDF::API2->open('my/old.pdf');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->open('our/to/be/updated.pdf');
+    ...
+    $pdf->update;
+
 =cut
 
 sub open {
@@ -209,6 +227,14 @@ sub open {
 
 Opens an existing PDF-stream for modification.
 
+B<Example:>
+
+    open($fh,'our/stream.pdf') or die "$@";
+    @pdf = <$fh>;
+    $pdf = PDF::API->openScalar(join('',@pdf));
+    ...
+    $pdf->saveas('our/new.pdf');
+
 =cut
 
 sub openScalar {
@@ -512,13 +538,13 @@ sub isEncrypted {
     return(defined($self->{pdf}->{'Encrypt'}) ? 1 : 0);
 }
     
-=item %infohash $pdf->info %infohash
+=item %infohash = $pdf->info %infohash
 
 Sets/Gets the info structure of the document.
 
 B<Example:>
 
-    $pdf->info(
+    %h = $pdf->info(
         'Author'       => " Alfred Reibenschuh ",
         'CreationDate' => "D:20020911000000+01'00'",
         'ModDate'      => "D:YYYYMMDDhhmmssOHH'mm'",
@@ -528,6 +554,8 @@ B<Example:>
         'Subject'      => "perl ?",
         'Keywords'     => "all good things are pdf"
     );
+    print "Author: $h{Author}\n";
+    
 
 =cut
 
@@ -578,6 +606,13 @@ sub info {
 
 Sets/Gets the supported info-structure tags.
 
+B<Example:>
+
+    @attrs = $pdf->infoMetaAttributes;
+    print "Supported Attributes: @attr\n";
+    @attrs = $pdf->infoMetaAttributes('CustomField1');
+    print "Supported Attributes: @attr\n";
+
 =cut
 
 sub infoMetaAttributes 
@@ -594,6 +629,26 @@ sub infoMetaAttributes
 
 Sets/Gets the XMP XML data-stream.
 
+B<Example:>
+
+    $xml = $pdf->xmpMetadata;
+    print "PDFs Metadata reads: $xml\n";
+    $xml=<<EOT;
+    <?xpacket begin='﻿' id='W5M0MpCehiHzreSzNTczkc9d'?>
+    <?adobe-xap-filters esc="CRLF"?>
+    <x:xmpmeta xmlns:x='adobe:ns:meta/' x:xmptk='XMP toolkit 2.9.1-14, framework 1.6'>
+    <rdf:RDF xmlns:rdf='http://www.w3.org/1999/02/22-rdf-syntax-ns#' xmlns:iX='http://ns.adobe.com/iX/1.0/'>
+    <rdf:Description rdf:about='uuid:b8659d3a-369e-11d9-b951-000393c97fd8' xmlns:pdf='http://ns.adobe.com/pdf/1.3/' pdf:Producer='Acrobat Distiller 6.0.1 for Macintosh'></rdf:Description>
+    <rdf:Description rdf:about='uuid:b8659d3a-369e-11d9-b951-000393c97fd8' xmlns:xap='http://ns.adobe.com/xap/1.0/' xap:CreateDate='2004-11-14T08:41:16Z' xap:ModifyDate='2004-11-14T16:38:50-08:00' xap:CreatorTool='FrameMaker 7.0' xap:MetadataDate='2004-11-14T16:38:50-08:00'></rdf:Description>
+    <rdf:Description rdf:about='uuid:b8659d3a-369e-11d9-b951-000393c97fd8' xmlns:xapMM='http://ns.adobe.com/xap/1.0/mm/' xapMM:DocumentID='uuid:919b9378-369c-11d9-a2b5-000393c97fd8'/>
+    <rdf:Description rdf:about='uuid:b8659d3a-369e-11d9-b951-000393c97fd8' xmlns:dc='http://purl.org/dc/elements/1.1/' dc:format='application/pdf'><dc:description><rdf:Alt><rdf:li xml:lang='x-default'>Adobe Portable Document Format (PDF)</rdf:li></rdf:Alt></dc:description><dc:creator><rdf:Seq><rdf:li>Adobe Systems Incorporated</rdf:li></rdf:Seq></dc:creator><dc:title><rdf:Alt><rdf:li xml:lang='x-default'>PDF Reference, version 1.6</rdf:li></rdf:Alt></dc:title></rdf:Description>
+    </rdf:RDF>
+    </x:xmpmeta>
+    <?xpacket end='w'?>
+    EOT
+    $xml = $pdf->xmpMetadata($xml);
+    print "PDFs Metadata now reads: $xml\n";
+    
 =cut
 
 sub xmpMetadata {
@@ -628,7 +683,15 @@ sub xmpMetadata {
 
 =item $pdf->finishobjects @objects
 
-Force objects to be written to file.
+Force objects to be written to file if available.
+
+B<Example:>
+
+    $pdf = PDF::API2->new(-file => 'our/new.pdf');
+    ...
+    $pdf->finishobjects($page, $gfx, $txt);
+    ...
+    $pdf->save;
 
 =cut
 
@@ -674,6 +737,12 @@ sub proc_pages {
 
 Updates a previously "opened" document after all changes have been applied.
 
+B<Example:>
+
+    $pdf = PDF::API2->open('our/to/be/updated.pdf');
+    ...
+    $pdf->update;
+
 =cut
 
 sub update {
@@ -685,6 +754,12 @@ sub update {
 
 Saves the document to file.
 
+B<Example:>
+
+    $pdf = PDF::API2->new();
+    ...
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub saveas {
@@ -729,6 +804,12 @@ sub save_xml {
 
 Returns the document in a string.
 
+B<Example:>
+
+    $pdf = PDF::API2->new();
+    ...
+    print $pdf->stringify;
+
 =cut
 
 sub stringify {
@@ -824,6 +905,13 @@ B<Note:> on $index
     -1,0 ... returns the last page
     1 ... returns page number 1
 
+B<Example:> (A Document with 99 Pages)
+
+    $page = $pdf->openpage(1);   # returns the first page
+    $page = $pdf->openpage(99);  # returns the last page
+    $page = $pdf->openpage(-1);  # returns the last page
+    $page = $pdf->openpage(999); # returns undef
+
 =cut
 
 sub openpage {
@@ -843,6 +931,8 @@ sub openpage {
     {
         $page=$self->{pagestack}->[$index-1];
     }
+    return undef unless(ref $page);
+    
     if(ref($page) ne 'PDF::API2::Page') 
     {
         bless($page,'PDF::API2::Page');
@@ -986,6 +1076,16 @@ B<Note:> on $index
     -1,0 ... returns the last page
     1 ... returns page number 1
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $old = PDF::API2->open('my/old.pdf');
+    $xo = $pdf->importPageIntoForm($old,2); # get page 2
+    $page = $pdf->page;
+    $gfx = $page->gfx;
+    $gfx->formimage($xo,0,0,1); # put it on page 1 with scale x1
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub importPageIntoForm {
@@ -1074,6 +1174,13 @@ B<Note:> on $index
 B<Note:> you can specify a page object instead as $targetindex
 so that the contents of the sourcepage will be 'merged into'.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $old = PDF::API2->open('my/old.pdf');
+    $page = $pdf->importPage($old,2); # get page 2 into page 1
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 # B<Note:> the interactive forms of a page will also be imported, but may
@@ -1203,6 +1310,24 @@ sub pages {
 
 Sets the global mediabox. Other methods: cropbox, bleedbox, trimbox and artbox.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $pdf->mediabox('A4');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->mediabox(595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->mediabox(0,0,595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+
 =cut
 
 sub mediabox {
@@ -1219,6 +1344,23 @@ sub mediabox {
 
 Sets the global cropbox.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $pdf->cropbox('A4');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->cropbox(595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->cropbox(0,0,595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub cropbox {
@@ -1235,6 +1377,23 @@ sub cropbox {
 
 Sets the global bleedbox.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $pdf->bleedbox('A4');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->bleedbox(595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->bleedbox(0,0,595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub bleedbox {
@@ -1251,6 +1410,23 @@ sub bleedbox {
 
 Sets the global trimbox.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $pdf->trimbox('A4');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->trimbox(595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->trimbox(0,0,595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub trimbox {
@@ -1267,6 +1443,23 @@ sub trimbox {
 
 Sets the global artbox.
 
+B<Example:>
+
+    $pdf = PDF::API2->new;
+    $pdf->artbox('A4');
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->artbox(595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
+    $pdf = PDF::API2->new;
+    $pdf->artbox(0,0,595,842);
+    ...
+    $pdf->saveas("our/new.pdf");
+
 =cut
 
 sub artbox {
@@ -2208,6 +2401,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: API2.pm,v $
+    Revision 1.80  2005/06/10 16:12:49  fredo
+    documentation update
+
     Revision 1.79  2005/03/23 16:42:06  fredo
     fixed typo in infoMetaAttributes
 
