@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Text.pm,v 1.7 2004/12/16 00:30:53 fredo Exp $
+#   $Id: Text.pm,v 1.8 2005/03/14 22:01:06 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Content::Text;
@@ -43,7 +43,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Content);
 
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
+    ( $VERSION ) = '$Revision: 1.8 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:06 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -72,6 +72,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Text.pm,v $
+    Revision 1.8  2005/03/14 22:01:06  fredo
+    upd 2005
+
     Revision 1.7  2004/12/16 00:30:53  fredo
     added no warn for recursion
 
