@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Page.pm,v 1.8 2004/09/13 15:27:59 fredo Exp $
+#   $Id: Page.pm,v 1.11 2005/06/14 12:54:16 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Page;
@@ -52,10 +52,12 @@ BEGIN {
     use POSIX qw(floor ceil);
     use Math::Trig;
 
-    ( $VERSION ) = '$Revision: 1.8 $' =~ /Revision: (\S+)\s/; # $Date: 2004/09/13 15:27:59 $
+    ( $VERSION ) = '$Revision: 1.11 $' =~ /Revision: (\S+)\s/; # $Date: 2005/06/14 12:54:16 $
 
 }
 
+no warnings qw[ deprecated recursion uninitialized ];
+
 =head1 $page = PDF::API2::Page->new $pdf, $parent, $index
 
 Returns a page object (called from $pdf->page).
@@ -376,6 +378,11 @@ sub annotation {
     $ant->{' apipdf'}=$self->{' apipdf'};
     $ant->{' apipage'}=$self;
 
+    if($self->{'Annots'}->is_obj($self->{' apipdf'}))
+    {
+        $self->{' apipdf'}->out_obj($self->{'Annots'});
+    }
+
     return($ant);
 }
 
@@ -455,6 +462,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Page.pm,v $
+    Revision 1.11  2005/06/14 12:54:16  fredo
+    fix for existing annotation dictionary (ex. ScanSoft PDF)
+
+    Revision 1.10  2005/03/14 22:01:05  fredo
+    upd 2005
+
+    Revision 1.9  2004/12/16 00:30:52  fredo
+    added no warn for recursion
+
     Revision 1.8  2004/09/13 15:27:59  fredo
     added rotate for acrobat-wise pdf-creators
 
