@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: courier.pm,v 1.6 2004/12/16 01:09:12 fredo Exp $
+#   $Id: courier.pm,v 1.8 2005/06/07 23:21:39 fredo Exp $
 #
 #=======================================================================
 
 $fonts->{courier}= {
     'fontname' => 'Courier',
     'type' => 'Type1',
-    'apiname' => 'Co1',
+    'apiname' => 'Cour',
     'ascender' => '629',
     'capheight' => '562',
     'descender' => '-157',
@@ -635,6 +635,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: courier.pm,v $
+    Revision 1.8  2005/06/07 23:21:39  fredo
+    fontkey correction
+
+    Revision 1.7  2005/03/14 22:01:28  fredo
+    upd 2005
+
     Revision 1.6  2004/12/16 01:09:12  fredo
     updated to new adobe afm
 
