@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: timesitalic.pm,v 1.6 2005/03/14 22:01:29 fredo Exp $
+#   $Id: timesitalic.pm,v 1.7 2005/06/07 23:21:40 fredo Exp $
 #
 #=======================================================================
 
 $fonts->{timesitalic}= {
     'fontname' => 'Times-Italic',
     'type' => 'Type1',
-    'apiname' => 'Ti4',
+    'apiname' => 'TiIt',
     'ascender' => '683',
     'capheight' => '653',
     'descender' => '-217',
@@ -553,6 +553,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: timesitalic.pm,v $
+    Revision 1.7  2005/06/07 23:21:40  fredo
+    fontkey correction
+
     Revision 1.6  2005/03/14 22:01:29  fredo
     upd 2005
 
